@@ -37,15 +37,15 @@ class KonqHistoryModel : public QAbstractItemModel
     Q_OBJECT
 
 public:
-    explicit KonqHistoryModel(QObject *parent = Q_NULLPTR);
-    ~KonqHistoryModel();
+    explicit KonqHistoryModel(QObject *parent = nullptr);
+    ~KonqHistoryModel() override;
 
     // reimplementations from QAbstractItemModel
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex &index) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
     void deleteItem(const QModelIndex &index);
 
